@@ -18,9 +18,9 @@ class MustVerifyEmail:
         mail = mail_manager.helper()
         sign = Sign()
 
-        token = sign.sign('{0}::{1}'.format(self.id, time.time()))
-        link = '{0}/email/verify/{1}'.format(request.environ['HTTP_HOST'], token)
+        token = sign.sign("{0}::{1}".format(self.id, time.time()))
+        link = "{0}/email/verify/{1}".format(request.environ["HTTP_HOST"], token)
 
-        mail.to(self.email) \
-            .template('auth/verifymail', {'name': self.name, 'email': self.email, 'link': link}) \
-            .subject('Please Confirm Your Email').send()
+        mail.to(self.email).template(
+            "auth/verifymail", {"name": self.name, "email": self.email, "link": link}
+        ).subject("Please Confirm Your Email").send()
